@@ -1,4 +1,4 @@
-/* $XFree86: xc/extras/Mesa/src/mesa/drivers/dri/r128/r128_tris.c,v 1.1.1.3 2004/12/10 15:32:58 alanh Exp $ */ /* -*- c-basic-offset: 3 -*- */
+/* $XFree86: xc/extras/Mesa/src/mesa/drivers/dri/r128/r128_tris.c,v 1.2 2007/09/16 03:44:16 tsi Exp $ */
 /**************************************************************************
 
 Copyright 2000, 2001 ATI Technologies Inc., Ontario, Canada, and
@@ -217,7 +217,7 @@ do {							\
 
 #define LOCAL_VARS(n)						\
    r128ContextPtr rmesa = R128_CONTEXT(ctx);			\
-   GLuint color[n], spec[n];					\
+   GLuint color[n] = {0, }, spec[n] = {0, };			\
    GLuint coloroffset = rmesa->coloroffset;			\
    GLuint specoffset = rmesa->specoffset;			\
    GLboolean havespec = (rmesa->specoffset != 0);		\
