@@ -19,7 +19,7 @@ INCIDENTAL OR CONSEQUENTIAL DAMAGES, ARISING OUT OF OR IN ANY WAY CONNECTED
 WITH THE SPEEDO SOFTWARE OR THE BITSTREAM CHARTER OUTLINE FONT.
 
 */
-/* $XFree86: xc/lib/font/Speedo/iface.c,v 1.4 2006/01/09 14:59:27 dawes Exp $ */
+/* $XFree86: xc/lib/font/Speedo/iface.c,v 1.5 2006/12/10 15:58:24 tsi Exp $ */
 
 /***************************** I F A C E . C *********************************
  *                                                                           *
@@ -35,11 +35,13 @@ WITH THE SPEEDO SOFTWARE OR THE BITSTREAM CHARTER OUTLINE FONT.
 #include "xf86_ansic.h"
 #endif
 
-#define   DEBUG      0
+#ifndef DEBUG
+#define DEBUG 0
+#endif
 
 #if DEBUG
 #include <stdio.h>
-#define SHOW(X) printf("X = %d\n", X)
+#define SHOW(X) printf("X = %lx\n", (unsigned long)X)
 #else
 #define SHOW(X)
 #endif
