@@ -19,7 +19,7 @@ INCIDENTAL OR CONSEQUENTIAL DAMAGES, ARISING OUT OF OR IN ANY WAY CONNECTED
 WITH THE SPEEDO SOFTWARE OR THE BITSTREAM CHARTER OUTLINE FONT.
 
 */
-/* $XFree86: xc/lib/font/Speedo/out_scrn.c,v 1.6 2006/01/09 14:59:27 dawes Exp $ */
+/* $XFree86: xc/lib/font/Speedo/out_scrn.c,v 1.7 2006/12/10 15:58:24 tsi Exp $ */
 
 
 /*************************** O U T _ S C R N . C *****************************
@@ -31,18 +31,19 @@ WITH THE SPEEDO SOFTWARE OR THE BITSTREAM CHARTER OUTLINE FONT.
 
 #include "spdo_prv.h"               /* General definitions for Speedo   */
 
+#ifndef   DEBUG
 #define   DEBUG      0
+#endif
 #define   LOCAL      static
 #define   ABS(X)     ( (X < 0) ? -X : X)
 
 #if DEBUG
 #include <stdio.h>
-#define SHOW(X) printf("X = %d\n", X)
+#define SHOW(X) printf("X = %lx\n", (unsigned long)X)
 #else
 #define SHOW(X)
 #endif
 
-
 /***** GLOBAL VARIABLES *****/
 
 /***** GLOBAL FUNCTIONS *****/
