@@ -20,7 +20,7 @@ OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN
 THE SOFTWARE.
 */
 
-/* $XFree86: xc/lib/font/fontfile/encparse.c,v 1.19 2003/12/19 02:05:38 dawes Exp $ */
+/* $XFree86: xc/lib/font/fontfile/encparse.c,v 1.23 2004/10/23 15:29:26 dawes Exp $ */
 
 /* Parser for encoding files */
 
@@ -32,7 +32,7 @@ THE SOFTWARE.
 #include <string.h>
 #include <stdio.h>
 
-#ifdef SCO325
+#ifdef __SCO__
 #include <strings.h>
 #endif
 
@@ -579,8 +579,6 @@ parseEncodingFile(FontFilePtr f, int headerOnly)
         } else {                /* unknown mapping type -- ignore */
             goto skipmapping;
         }
-        /* NOTREACHED */
-        goto error;
     default: goto no_mapping;   /* ignore unknown lines */
     }
 
@@ -837,6 +835,7 @@ FontEncReallyReallyLoad(const char *charset,
     char file_name[MAXFONTFILENAMELEN], encoding_name[MAXFONTNAMELEN],
         buf[MAXFONTFILENAMELEN];
     int count, n;
+    static char format[24] = "";
     
     /* As we don't really expect to open encodings that often, we don't
        take the trouble of caching encodings directories. */
@@ -852,8 +851,12 @@ FontEncReallyReallyLoad(const char *charset,
     }
 
     encoding = NULL;
+    if (!format[0]) {
+	sprintf(format, "%%%ds %%%d[^\n]\n", (int)sizeof(encoding_name) - 1,
+		(int)sizeof(file_name) - 1);
+    }
     for(;;) {
-        count = fscanf(file, "%s %[^\n]\n", encoding_name, file_name);
+        count = fscanf(file, format, encoding_name, file_name);
         if(count == EOF)
             break;
         if(count != 2)
