@@ -1,4 +1,3 @@
-/* $Xorg: lbxfuncs.c,v 1.3 2000/08/17 19:53:55 cpqbld Exp $ */
 /*
  * Copyright 1994 Network Computing Devices, Inc.
  * Copyright 1996 X Consortium, Inc.
@@ -22,7 +21,7 @@
  * CONNECTION WITH THE USE OR PERFORMANCE OF THIS SOFTWARE.
  *
  */
-/* $XFree86: xc/programs/lbxproxy/di/lbxfuncs.c,v 1.7 2003/05/27 22:26:56 tsi Exp $ */
+/* $XFree86: xc/programs/lbxproxy/di/lbxfuncs.c,v 1.9 2006/01/09 15:00:45 dawes Exp $ */
 
 /*
  * top level LBX request & reply handling
@@ -41,6 +40,7 @@
 #include	<stdio.h>
 #include	"assert.h"
 #include	"lbx.h"
+#include        "gfx.h"
 #include	"atomcache.h"
 #include	"util.h"
 #include	"init.h"
@@ -50,19 +50,37 @@
 #include	"swap.h"
 #include	"reqtype.h"
 #include	"lbxext.h"
+#include        "lbxfuncs.h"
 #include	"proxyopts.h"
 
-#ifdef DEBUG
-extern int lbxDebug;
-#endif
-
-static Bool intern_atom_reply();
-static Bool get_atom_name_reply();
-static Bool get_mod_map_reply();
-static Bool get_key_map_reply();
-static Bool sync_reply();
-static Bool get_queryfont_reply();
-static Bool GetWinAttrAndGeomReply();
+static Bool intern_atom_reply(
+    ClientPtr   client,
+    ReplyStuffPtr nr,
+    char       *data);
+static Bool get_atom_name_reply(
+    ClientPtr   client,
+    ReplyStuffPtr nr,
+    char       *data);
+static Bool get_mod_map_reply(
+    ClientPtr   client,
+    ReplyStuffPtr nr,
+    char       *data);
+static Bool get_key_map_reply(
+    ClientPtr   client,
+    ReplyStuffPtr nr,
+    char       *data);
+static Bool sync_reply(
+    ClientPtr   client,
+    ReplyStuffPtr nr,
+    char       *data);
+static Bool get_queryfont_reply(
+    ClientPtr   client,
+    ReplyStuffPtr nr,
+    char       *data);
+static Bool GetWinAttrAndGeomReply(
+    ClientPtr   client,
+    ReplyStuffPtr nr,
+    char       *data);
 
 #define reply_length(cp,rep) ((rep)->type==X_Reply ? \
         32 + (HostUnswapLong((cp),(rep)->length) << 2) \
@@ -72,13 +90,13 @@ char protocolMode = PROTOCOL_FULL;
 
 /* ARGSUSED */
 static void 
-get_connection_info(client, cs, cs_len, change_type, changes, changes_len)
-    ClientPtr   client;
-    xConnSetup *cs;
-    int		cs_len;
-    int		change_type;
-    CARD32     *changes;
-    int		changes_len;
+get_connection_info(
+    ClientPtr   client,
+    xConnSetup *cs,
+    int		cs_len,
+    int		change_type,
+    CARD32     *changes,
+    int		changes_len)
 {
     xWindowRoot *root;
     xDepth     *depth;
@@ -155,6 +173,7 @@ send_setup_reply(ClientPtr client, Bool success, int majorVer, int minorVer,
 	WriteSConnSetupPrefix(client, &reply);
     else
 	(void)WriteToClient(client, sizeof(xConnSetupPrefix), (char *) &reply);
+	
     if (success && client->swapped)
 	WriteSConnectionInfo(client, (unsigned long)(reply.length << 2), cs);
     else
@@ -162,15 +181,15 @@ send_setup_reply(ClientPtr client, Bool success, int majorVer, int minorVer,
 }
 
 static void
-finish_setup_reply(client, cs, cs_len, change_type, changes, changes_len, majorVer, minorVer)
-    ClientPtr   client;
-    xConnSetup *cs;
-    int         cs_len;
-    int		change_type;
-    CARD32*     changes;
-    int		changes_len;
+finish_setup_reply(
+    ClientPtr   client,
+    xConnSetup *cs,
+    int         cs_len,
+    int		change_type,
+    CARD32*     changes,
+    int		changes_len,
     int		majorVer,
-                minorVer;
+    int         minorVer)
 {
     get_connection_info(client, cs, cs_len, change_type, changes, changes_len);
     client->minKeyCode = cs->minKeyCode;
@@ -192,10 +211,10 @@ finish_setup_reply(client, cs, cs_len, change_type, changes, changes_len, majorV
  */
 
 static void
-get_setup_reply(client, data, len)
-    ClientPtr   client;
-    char       *data;
-    int		len;
+get_setup_reply(
+    ClientPtr   client,
+    char       *data,
+    int		len)
 {
     register xLbxConnSetupPrefix *rep;
     TagData     td;
@@ -270,8 +289,8 @@ get_setup_reply(client, data, len)
 }
 
 int
-ProcLBXInternAtom(client)
-    ClientPtr   client;
+ProcLBXInternAtom(
+    ClientPtr   client)
 {
     REQUEST(xInternAtomReq);
     char       *s;
@@ -301,7 +320,7 @@ ProcLBXInternAtom(client)
 	    SwapInternAtomReply(&reply);
 	if (LBXCacheSafe(client)) {
 	    FinishLBXRequest(client, REQ_YANK);
-	    WriteToClient(client, sizeof(xInternAtomReply), &reply);
+	    WriteToClient(client, sizeof(xInternAtomReply), (char*)&reply);
 	} else {			/* store for later */
 	    if (!LBXCanDelayReply(client))
 		SendLbxSync(client);
@@ -333,10 +352,10 @@ ProcLBXInternAtom(client)
 }
 
 static Bool
-intern_atom_reply(client, nr, data)
-    ClientPtr   client;
-    ReplyStuffPtr nr;
-    char       *data;
+intern_atom_reply(
+    ClientPtr   client,
+    ReplyStuffPtr nr,
+    char       *data)
 {
     Atom        atom;
     char       *str;
@@ -360,8 +379,8 @@ intern_atom_reply(client, nr, data)
 }
 
 int
-ProcLBXGetAtomName(client)
-    ClientPtr   client;
+ProcLBXGetAtomName(
+    ClientPtr   client)
 {
     REQUEST(xResourceReq);
     char       *str;
@@ -387,7 +406,7 @@ ProcLBXGetAtomName(client)
 	    SwapGetAtomNameReply(&reply);
 	if (LBXCacheSafe(client)) {
 	    FinishLBXRequest(client, REQ_YANK);
-	    WriteToClient(client, sizeof(xGetAtomNameReply), &reply);
+	    WriteToClient(client, sizeof(xGetAtomNameReply), (char*)&reply);
 	    WriteToClient(client, len, str);
 	} else {
 	    if (!LBXCanDelayReply(client))
@@ -416,10 +435,10 @@ ProcLBXGetAtomName(client)
 }
 
 static Bool
-get_atom_name_reply(client, nr, data)
-    ClientPtr   client;
-    ReplyStuffPtr nr;
-    char       *data;
+get_atom_name_reply(
+    ClientPtr   client,
+    ReplyStuffPtr nr,
+    char       *data)
 {
     Atom        atom;
     char       *s;
@@ -453,8 +472,8 @@ get_atom_name_reply(client, nr, data)
  */
 
 void
-SendLbxSync (client)
-    ClientPtr client;
+SendLbxSync (
+    ClientPtr client)
 {
     xLbxSyncReq req;
     ReplyStuffPtr nr;
@@ -475,22 +494,22 @@ SendLbxSync (client)
 
 /* ARGSUSED */
 static Bool
-sync_reply(client, nr, data)
-    ClientPtr   client;
-    ReplyStuffPtr nr;
-    char       *data;
+sync_reply(
+    ClientPtr   client,
+    ReplyStuffPtr nr,
+    char       *data)
 {
     /* do nothing; just here to catch and discard the reply */
     return TRUE;
 }
 
 void
-WriteError(client, majorCode, minorCode, resId, errorCode)
-    ClientPtr client;
-    unsigned int majorCode;
-    unsigned int minorCode;
-    XID resId;
-    int errorCode;
+WriteError(
+    ClientPtr client,
+    unsigned int majorCode,
+    unsigned int minorCode,
+    XID resId,
+    int errorCode)
 {
     xError      rep;
     int		n;
@@ -512,8 +531,8 @@ WriteError(client, majorCode, minorCode, resId, errorCode)
 }
 
 int
-ProcLBXGetModifierMapping(client)
-    ClientPtr   client;
+ProcLBXGetModifierMapping(
+    ClientPtr   client)
 {
     ReplyStuffPtr nr;
 
@@ -529,10 +548,10 @@ ProcLBXGetModifierMapping(client)
 
 /*ARGSUSED*/
 static Bool
-get_mod_map_reply(client, nr, data)
-    ClientPtr   client;
-    ReplyStuffPtr nr;
-    char       *data;
+get_mod_map_reply(
+    ClientPtr   client,
+    ReplyStuffPtr nr,
+    char       *data)
 {
     xLbxGetModifierMappingReply *rep;
     int         len;
@@ -592,15 +611,15 @@ get_mod_map_reply(client, nr, data)
     reply.length = len >> 2;
     if (client->swapped)
 	SwapModmapReply(&reply);
-    WriteToClient(client, sizeof(xGetModifierMappingReply), &reply);
+    WriteToClient(client, sizeof(xGetModifierMappingReply), (char*)&reply);
     WriteToClient(client, len, tag_data);
 
     return TRUE;
 }
 
 int
-ProcLBXGetKeyboardMapping(client)
-    ClientPtr   client;
+ProcLBXGetKeyboardMapping(
+    ClientPtr   client)
 {
     REQUEST(xGetKeyboardMappingReq);
     ReplyStuffPtr nr;
@@ -624,10 +643,10 @@ ProcLBXGetKeyboardMapping(client)
  */
 
 static Bool
-get_key_map_reply(client, nr, data)
-    ClientPtr   client;
-    ReplyStuffPtr nr;
-    char       *data;
+get_key_map_reply(
+    ClientPtr   client,
+    ReplyStuffPtr nr,
+    char       *data)
 {
     xLbxGetKeyboardMappingReply *rep;
     int         len;
@@ -713,7 +732,7 @@ get_key_map_reply(client, nr, data)
 	}
     } else
 	sdata = tag_data;
-    WriteToClient(client, sizeof(xGetKeyboardMappingReply), &reply);
+    WriteToClient(client, sizeof(xGetKeyboardMappingReply), (char*)&reply);
     WriteToClient(client, len, sdata);
     if (sdata != tag_data)
 	DEALLOCATE_LOCAL(sdata);
@@ -722,8 +741,8 @@ get_key_map_reply(client, nr, data)
 }
 
 int
-ProcLBXQueryFont(client)
-    ClientPtr   client;
+ProcLBXQueryFont(
+    ClientPtr   client)
 {
     REQUEST(xResourceReq);
     ReplyStuffPtr nr;
@@ -745,11 +764,11 @@ ProcLBXQueryFont(client)
 }
 
 static INT16
-unpack_val(val, mask, sft, bts)
-    CARD32      val;
-    CARD32      mask;
+unpack_val(
+    CARD32      val,
+    CARD32      mask,
     int         sft,
-                bts;
+    int         bts)
 {
     CARD16      utmp;
     INT16       sval;
@@ -841,10 +860,10 @@ UnsquishFontInfo(int compression, xLbxFontInfo *fdata, int dlen, pointer *qfr)
 
 /*ARGSUSED*/
 static Bool
-get_queryfont_reply(client, nr, data)
-    ClientPtr   client;
-    ReplyStuffPtr nr;
-    char       *data;
+get_queryfont_reply(
+    ClientPtr   client,
+    ReplyStuffPtr nr,
+    char       *data)
 {
     xLbxQueryFontReply *rep;
     int         len,
@@ -927,8 +946,8 @@ get_queryfont_reply(client, nr, data)
 	len -= sizeof(xQueryFontReply);
 	if (client->swapped)
 	    SwapFont(reply, TRUE);
-	WriteToClient(client, sizeof(xQueryFontReply), reply);
-	WriteToClient(client, len, reply + 1);
+	WriteToClient(client, sizeof(xQueryFontReply), (char*)reply);
+	WriteToClient(client, len, (char*)(reply + 1));
 	DEALLOCATE_LOCAL(reply);
     }
 
@@ -939,8 +958,8 @@ get_queryfont_reply(client, nr, data)
 
 
 int
-ProcLBXGetWindowAttributes(client)
-    ClientPtr   client;
+ProcLBXGetWindowAttributes(
+    ClientPtr   client)
 {
     REQUEST(xResourceReq);
     xLbxGetWinAttrAndGeomReq newreq;
@@ -984,10 +1003,10 @@ ProcLBXGetWindowAttributes(client)
 
 
 static Bool
-GetWinAttrAndGeomReply (client, nr, data)
-    ClientPtr   client;
-    ReplyStuffPtr nr;
-    char       *data;
+GetWinAttrAndGeomReply (
+    ClientPtr   client,
+    ReplyStuffPtr nr,
+    char       *data)
 {
     xLbxGetWinAttrAndGeomReply *lbxrep;
     xGetWindowAttributesReply reply;
@@ -1029,7 +1048,7 @@ GetWinAttrAndGeomReply (client, nr, data)
 	swapl (&reply.length, n);
     }
 
-    WriteToClient(client, sizeof(xGetWindowAttributesReply), &reply);
+    WriteToClient(client, sizeof(xGetWindowAttributesReply), (char*)&reply);
 
     if (nr->request_info.lbxWinGeom.got_geom_request)
     {
@@ -1054,7 +1073,7 @@ GetWinAttrAndGeomReply (client, nr, data)
 	    swaps (&geomReply.sequenceNumber, n);
 	}
 
-	WriteToClient(client, sizeof(xGetGeometryReply), &geomReply);
+	WriteToClient(client, sizeof(xGetGeometryReply), (char*)&geomReply);
 
 	LBXLastResponse(client) = lbxrep->sequenceNumber + 1;
  
@@ -1082,8 +1101,8 @@ GetWinAttrAndGeomReply (client, nr, data)
 
 
 int
-ProcLBXGetGeometry(client)
-    ClientPtr   client;
+ProcLBXGetGeometry(
+    ClientPtr   client)
 {
     /* REQUEST(xResourceReq); */
     xGetGeometryReply reply;
@@ -1132,7 +1151,7 @@ ProcLBXGetGeometry(client)
 	}
 
 	FinishLBXRequest(client, REQ_YANK);
-	WriteToClient(client, sizeof(xGetGeometryReply), &reply);
+	WriteToClient(client, sizeof(xGetGeometryReply), (char*)&reply);
 	RemoveReply (client, nr);
     }
     else
@@ -1151,8 +1170,8 @@ ProcLBXGetGeometry(client)
 
 /* We're just looking for signs of the window manager here */
 int
-ProcLBXChangeWindowAttributes(client)
-    ClientPtr client;
+ProcLBXChangeWindowAttributes(
+    ClientPtr client)
 {
     REQUEST(xChangeWindowAttributesReq);
     Window win;
@@ -1177,9 +1196,9 @@ ProcLBXChangeWindowAttributes(client)
 }
 
 void
-FinishLBXRequest(client, yank)
-    ClientPtr   client;
-    int         yank;
+FinishLBXRequest(
+    ClientPtr   client,
+    int         yank)
 {
     REQUEST(xReq);
     char        n;
@@ -1249,10 +1268,10 @@ FinishLBXRequest(client, yank)
  * QueryFont regularly hits this in normal operation
  */
 static int
-patchup_error(client, err, nr)
-    ClientPtr   client;
-    xError     *err;
-    ReplyStuffPtr nr;
+patchup_error(
+    ClientPtr   client,
+    xError     *err,
+    ReplyStuffPtr nr)
 {
     int         retval = 1;
     CARD16      minor_code;
@@ -1303,10 +1322,10 @@ patchup_error(client, err, nr)
 }
 
 static Bool
-error_matches(client, nr, err)
-    ClientPtr   client;
-    ReplyStuffPtr nr;
-    xError     *err;
+error_matches(
+    ClientPtr   client,
+    ReplyStuffPtr nr,
+    xError     *err)
 {
     CARD16      mc;
     char        n;
@@ -1323,10 +1342,10 @@ error_matches(client, nr, err)
  * FALSE if data is replaced
  */
 static Bool
-HandleReply(client, data, len)
-    ClientPtr   client;
-    char       *data;
-    int         len;
+HandleReply(
+    ClientPtr   client,
+    char       *data,
+    int         len)
 {
     xGenericReply *reply;
     xError     *err;
